#!/usr/bin/env ruby
#
# Samizdat member login
#
#   Copyright (c) 2002-2004  Dmitry Borodaenko <angdraug@debian.org>
#
#   This program is free software.
#   You can distribute/modify this program under the terms of
#   the GNU General Public License version 2 or later.
#

require 'samizdat'

session = Session.new

login, passwd = session.params %w[login passwd]

if login and passwd then
    session.open login, passwd
else
    session.redirect(session.base)
end
